#
# spec file for package python-pip-api
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pip-api
Version:        0.0.30
Release:        5.1
Summary:        The official unofficial pip API
License:        Apache-2.0
URL:            https://github.com/di/pip-api
Source0:        https://github.com/di/pip-api/releases/download/%{version}/pip-api-%{version}.tar.gz
Source1:        test-data.tar.gz
# PATCH-FIX-OPENSUSE We do not want a vendored packaging.
Patch0:         unvendor.patch
# PATCH-FIX-OPENSUSE Remove a test parameter that is broken with our shipped
# packaging.
Patch1:         support-packaging-changes.patch
BuildRequires:  %{python_module packaging >= 21.0}
BuildRequires:  %{python_module pip >= 22.1}
BuildRequires:  %{python_module pretend}
BuildRequires:  %{python_module pyparsing >= 2.4.7}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module virtualenv}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pip
BuildArch:      noarch
%python_subpackages

%description
The official unofficial pip API.

%prep
%autosetup -p1 -a 1 -n pip-api-%{version}
rm -Rf ./pip_api/_vendor

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Broken with current packaging ; requires network
%pytest -k 'not (test_installed_distributions_legacy_version or test_installed_distributions or test_invoke_install or test_invoke_uninstall or test_isolation or test_all_the_right_pips or test_version)'

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/pip_api
%{python_sitelib}/pip_api*info

%changelog
* Tue Jun  3 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Fri Nov 24 2023 Antonio Larrosa <alarrosa@suse.com>
- Skip more tests that need network access
* Tue Jun 13 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
- Fix required package versions.
* Fri Jun  2 2023 Steve Kowalik <steven.kowalik@suse.com>
- Skip PEP508 tests since they require the network.
* Tue Feb  7 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.0.30:
  * Support editable project location (#148)
  * Do not treat `--trusted-host` as a requirement (#136)
  * Expose whether a requirement is editable (#131)
  * Use correct long flag for requirements (#118)
  * Support for hashed requirements (#126)
  * Drop support for Python 3.6, test against pip==22.0.x (#127)
  * Pass PIP_DISABLE_PIP_VERSION_CHECK to all invocations (#114)
  * Support the --path parameter when calling pip list (#112)
  * Add support for parsing URL requirements (#109)
  * Allow installed_distributions to be filtered for global distributions (#103)
  * Support Python 3.10
  * Allow requirement markers to be parsed (#99)
  * Use pip list's JSON output for installed_distributions (#93)
  * Drop support for Python 3.5 (#94)
  * Add type hints (#97)
  * Ensure environment vars are passed to subprocess call (#68)
  * Drop support for Python 2.7
  * Add experimental PEP 650 support
  * Fix issue with handling LegacyVersions (#66)
  * Support Python 3.9
- Add patch support-packaging-changes.patch:
  * Drop a test parameter that doesn't work with our version of packaging.
- Include non-shipped test data as test-data.tar.gz.
- Switch to GitHub tarball for tests.
- Refresh unvendor.patch
* Mon Mar 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.0.14
  * Test against pip 19.2 to 20.0.2
  * Support Python 3.8
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.0.13:
  - Include six==1.12.0 as a vendored dependency (#42)
  - Upgrade vendored packaging==19.2
  - Upgrade vendored pyparsing==2.4.2
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.0.12:
  * Bugfix with relative paths (#39)
* Fri Jun  7 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.0.10
- add unvendor.patch
* Fri May 17 2019 Hardik Italia <hitalia@suse.com>
- Update to 0.0.8:
  * Handle editable installs
  * Ignore index url parameters in parse_requirements
  * Drop support for Python 3.4
  * Add support for pip 19.0, 19.0.1, 19.0.2, 19.0.3
* Fri Feb 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.0.5:
  * distribute tests and license
* Wed Feb 20 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by pytest-reqs
